@@ -1,4 +1,3 @@
-
 pub struct Resource {
     pub _type: String,
     pub name: String,
@@ -30,7 +29,7 @@ impl std::fmt::Display for Resource {
 }
 
 // TODO this can be stricter and we can split out the leaf nodes
-#[derive(Debug, PartialEq)]
+#[derive(Clone, Debug, Eq, Hash, PartialEq)]
 pub enum Value {
     String(String),
     RawReference(String),
