@@ -1,4 +1,5 @@
 mod hcl;
+mod utils;
 mod yaml;
 
 use anyhow::Result;
@@ -8,6 +9,7 @@ use hcl::Resource;
 use yaml::SloOuter;
 
 // TODO add integration tests
+// TODO update example yaml
 
 /// Converts Figure SLO YAML to HCL
 #[derive(Parser, Debug)]
@@ -42,18 +44,20 @@ fn main() -> Result<()> {
         let mut resources = Vec::<Resource>::default();
 
         for yaml in yamls {
-            let yaml: SloOuter = serde_yaml::from_str(yaml)?;
+            let outer: SloOuter = serde_yaml::from_str(yaml)?;
 
-            for slo in yaml.slos {
-                for sli in &slo.slis {
-                    resources.push(sli.as_ref().into());
+            for slo in &outer.slos {
+                for mut sli in slo.slis.clone() {
+                    sli.base_mut().default_from_parent(&outer)?;
+
+                    resources.push(sli.as_ref().resource(&outer));
                 }
 
-                resources.push(slo.as_ref().into());
+                resources.push(slo.as_ref().resource(&outer));
             }
         }
 
-        // sort resources by name so output ordering is deterministic
+        // sort resources by type, name so output ordering is deterministic
         resources.sort_by(|a, b| {
             if a._type != b._type {
                 a._type.cmp(&b._type)
